黑客帝国3：矩阵革命 (豆瓣)
Description: 黑客帝国3：矩阵革命电影简介和剧情介绍,黑客帝国3：矩阵革命影评、图片、预告片、影讯、论坛、在线购票
Keywords: 黑客帝国3：矩阵革命,The Matrix Revolutions,黑客帝国3：矩阵革命影评,剧情介绍,电影图片,预告片,影讯,在线购票,论坛

No.159豆瓣电影Top250

# 黑客帝国3：矩阵革命 The Matrix Revolutions (2003)

导演: 拉娜·沃卓斯基 / 莉莉·沃卓斯基
编剧: 莉莉·沃卓斯基 / 拉娜·沃卓斯基
主演: 基努·里维斯 / 劳伦斯·菲什伯恩 / 凯瑞-安·莫斯 / 雨果·维文 / 贾达·萍克·史密斯 / 凯特·宾汉 / 玛丽·爱丽丝 / 莫妮卡·贝鲁奇 / 埃茜·戴维斯 / 克里斯托弗·卡比 / 罗伯特·马莫内 / 罗宾·奈文 / 吉娜薇·欧瑞丽 / 诺娜·加耶 / 纳撒尼尔·利斯 / 哈里·列尼斯 / 哈罗德·佩里诺 / 鲁伯特·雷德 / 凯文·迈克尔·理查德森 / 大卫·罗伯茨 / 布鲁斯·斯宾斯 / 吉娜·托瑞斯 / 克莱顿·华生 / 赫尔穆特·巴凯蒂斯 / 邹兆龙 / 乔·曼宁 / Tanveer K. Atwal / 拉黑·休姆 / 康奈尔·韦斯特 / 伯纳德·怀特 / 朗贝尔·维尔森 / 安东尼·布兰登·黄 / 安东尼·泽比 / 克雷格·沃克
类型: 动作 / 科幻
制片国家/地区: 美国
语言: 英语 / 法语
上映日期: 2003-11-05(美国/中国大陆)
片长: 129 分钟
又名: 22世纪杀人网络3：惊变世纪(港) / 骇客任务完结篇：最后战役(台) / 廿二世纪杀人网络3：惊变世纪 / 黑客帝国3 / 骇客帝国3
IMDb: tt0242653
豆瓣评分
引用
8.8
426428人评价
5星
53.6%
4星
35.5%
3星
9.9%
2星
0.8%
1星
0.2%
好于 98% 科幻片
好于 98% 动作片
想看 看过
评价:
推荐

## 黑客帝国3：矩阵革命的剧情简介 · · · · · ·

第二集中，尼奥（基努·里维斯 Keanu Reeves 饰）没有能从内部摧毁“母体”，他的身体在真实世界的飞船上陷于昏迷，思想却被困在介于“母体”和真实世界的中间地带，这个地方由“火车人”控制。墨菲斯（劳伦斯·菲什伯恩 Laurence Fishburne 饰）和崔妮蒂（凯瑞-安·莫斯 Carrie-Anne Moss 饰）等人知道了尼奥的情况，在守护天使的带领下， 找到了“火车人”的控制者梅罗纹奇，经过一番激斗，将尼奥救了出来。
此时，电子乌贼部队对锡安发起了猛烈的攻击，人类组织所有机甲战士展开顽强的抵抗，形势危在旦夕；尼奥和崔妮蒂驾驶了一艘飞船克服重重困难，到达机器城市，尼奥终于见到了机器世界的统治者“机器大帝”，双方谈判并达成了协议：尼奥除掉不受“母体”控制的史密斯，以换取锡安的和平。
在“母体”中，尼奥和史密斯展开了关系人类生死存亡的最后决斗... (展开全部) 第二集中，尼奥（基努·里维斯 Keanu Reeves 饰）没有能从内部摧毁“母体”，他的身体在真实世界的飞船上陷于昏迷，思想却被困在介于“母体”和真实世界的中间地带，这个地方由“火车人”控制。墨菲斯（劳伦斯·菲什伯恩 Laurence Fishburne 饰）和崔妮蒂（凯瑞-安·莫斯 Carrie-Anne Moss 饰）等人知道了尼奥的情况，在守护天使的带领下， 找到了“火车人”的控制者梅罗纹奇，经过一番激斗，将尼奥救了出来。
此时，电子乌贼部队对锡安发起了猛烈的攻击，人类组织所有机甲战士展开顽强的抵抗，形势危在旦夕；尼奥和崔妮蒂驾驶了一艘飞船克服重重困难，到达机器城市，尼奥终于见到了机器世界的统治者“机器大帝”，双方谈判并达成了协议：尼奥除掉不受“母体”控制的史密斯，以换取锡安的和平。
在“母体”中，尼奥和史密斯展开了关系人类生死存亡的最后决斗。 ©豆瓣

## 黑客帝国3：矩阵革命的演职员 · · · · · · ( 全部 106 )

- 拉娜·沃卓斯基 导演
- 莉莉·沃卓斯基 导演
- 基努·里维斯 饰 Neo
- 劳伦斯·菲什伯恩 饰 Morpheus
- 凯瑞-安·莫斯 饰 Trinity
- 雨果·维文 饰 Agent Smith

## 黑客帝国3：矩阵革命的视频和图片 · · · · · · ( 预告片1 | 添加视频评论 | 图片655 · 添加 )

## 黑客帝国3：矩阵革命的获奖情况 · · · · · · ( 全部 )

- 第10届中国电影华表奖
- 优秀译制片奖(提名)

## 喜欢这部电影的人也喜欢 · · · · · ·

  黑客帝国2：重装上阵

  终结者2：审判日

  我，机器人

  这个男人来自地球

  变形金刚

  阿凡达

  E.T.外星人

  第九区

  钢铁侠

  2001太空漫游

我要写短评

## 黑客帝国3：矩阵革命的短评 · · · · · · ( 全部 48719 条 )

热门 / 最新 / 好友

### 1481 有用 西北一枝花袭人 看过 2007-10-06 21:41:08

严重被低估的好片。我走到哪里都为它叫好平反。

### 2096 有用 把渣害 看过 2011-05-05 23:25:24

一个bug和一个流氓软件打来打去，打来打去和打来打去

### 758 有用 Mr.5 看过 2017-03-21 21:54:15

见过太多的才子，才发现都是膜拜的傻子。 到底有多少的电影有你的影子。

### 642 有用 王大根 看过 2017-04-14 23:07:29

厉害的概念都在第一部了，后两部根本只有打打打打打嘛

### 287 有用 Q。 看过 2011-04-23 02:36:08

相对于第一部与第二部，这次的完结篇动作场面和特技场面大幅增加。以表达“和平”为战争的主要目的，并且还有几条感情分支为辅助，以大规模机器人作战和最终一战都堪称完美，也让这个经典的科幻作品画上了完美的休止符。★★★★

> 更多短评 48719条
为什么被折叠？ 有一些短评被折叠了
评论被折叠，是因为发布这条评论的帐号行为异常。评论仍可以被展开阅读，对发布人的账号不造成其他影响。如果认为有问题，可以联系豆瓣电影。
你关注的人还没写过短评
我要写影评

## 黑客帝国3：矩阵革命的影评 · · · · · · ( 全部 491 条 )

热门 / 最新 / 好友
碎片 2009-08-11 03:21:01

## 【Matrix的前世今生】-----黑客帝国全解析

这是我在网上看到解析的最好的一篇，真正解析的非常的透彻而且完美，不像很多解析完全是想当然=== 【Matrix的前世今生】-----黑客帝国全解析 　　转自pop社区 　　作者bmw2222 　　当我在11月5日下午2点整坐在华纳公司的电影院里，等着Matrix完结篇全球同步开始的 　　时候，... (展开)
4817 221 401回应 收起
samules 2014-10-30 23:55:44

## 转《黑客帝国》完全解析

这篇影评可能有剧透

万事皆有始亦有终——《The Matrix》影评之终结篇 　　 　　一、前言 　　从 Matrix I 到 Matrix III，整整四年，一对名叫沃卓斯基（导演加编剧）的兄弟给科幻电影带来一次史无前例的冲击，无论从思想上还是视觉效果上都超过了以往任何一部科幻电影，从来没有一部科幻电影能够... (展开)
644 20 68回应 收起
hemingway 2005-12-03 12:33:49

## 社会冲突理论和结构功能主义的双重体现

matrix营造了一个非同一般的幻境。这个幻境的理解很需要人来费一番周章。 zion和ai应该都是matrix的两个系统，在这两个系统当中zion代表着那些反叛主义者的力量，他们竭尽所能维持自我生存的意义。而在ai的世界里，人们就是一个个既定的程序，在程序中体现着自己的功能。z... (展开)
394 69 77回应 收起
姜海滨 2009-03-17 11:17:46

## 自由意志的胜利

Neo坐着由Trinity（圣父圣子圣灵三位一体）驾驶的Logos号飞船（逻各斯在希腊语中有真理或“道”的意思），穿越封锁冲出云层，进入Matrix，以自己的生命换取人与机器的和平，救赎了世界（隐喻耶稣殉道）。 这个精彩的故事里蕴含着深刻的哲学和宗教寓意，也有政治的暗示。Smith是... (展开)
418 34 40回应 收起
ak650 2008-09-04 17:34:15

## matrix在升级...

这篇影评可能有剧透

连续3天，终于看完了3部。首先让我要承认这是一部值得看的电影。作为一个作品，如果要成为经典，而不是一时的流行，那就是它里面有着一些东西，这些东西让人们看着不只是惊奇一时而可以反复回味，而且在不同的人眼里，会看出不同的东西。就像莎士比亚的哈姆雷特。说到经典，让... (展开)
396 83 98回应 收起
Neo 2019-05-17 17:46:11

## 《黑客帝国系列》之百遍观感III：人类答卷

这篇影评可能有剧透

三篇顺序使用，效果最佳，奉上链接如下： 《黑客帝国》的豆瓣影评:【《黑客帝国系列》之百遍观感I：终极解答】 ： https://www.douban.com/doubanapp/dispatch/review/10077344 《黑客帝国2：重装上阵》的豆瓣影评:【《黑客帝国系列》之百遍观感II：进化实验】： [《黑客帝国系... (展开)
134 3 70回应 收起
漠墨 2011-10-22 10:15:34

## For Smith

“等等！我曾遇见过这一幕。你像这样躺在这里。我站在这里，该说些什么……一切有始有终？” “这是个阴谋！” 他惊恐绝望地说。 在即将给予对手致命一击之际，已被吞噬的先知从意识中显现。他突然明白了。明白了前世今生的一切一切。明白自己的生命已走到尽头。不可抗拒，... (展开)
91 11 10回应 收起
Mr.Child 2017-04-22 11:26:44

## 没看懂？其实这里面藏着一部佛学启示录

1999年，首部《黑客帝国》上映， 这部片子颠覆了很多人的世界观。 许多人从不同维度解释，发现其实都是有漏洞。 特别是第二部，第三部越看越糊涂。 为什么Neo面对机器乌贼有超能力， 为什么第6代救世主能拯救锡安， 电脑和人类社会的关系到底什么... 如今回忆起来，我越来... (展开)
96 7 8回应 收起
红锈宝刀侠 2005-09-04 12:33:00

## 系统冲突和平衡

Matrix I 获得热烈的赞誉。除了视觉效果还有哲学的探讨。可惜的是，大部分人感兴趣，甚至认同的是第一部的系统外系统衍生的观念。任何强调心理作用以及思辨的哲学命题都容易让现代人共鸣吧。 这未免有点可惜。 紧凑衔接用的第二部和终结的第三部才是这个哲学命题... (展开)
87 29 19回应 收起
Maxthor 2019-05-03 23:04:26

## 论《黑客帝国》系列中的角色命名与隐喻

这篇影评可能有剧透

《黑客帝国》是1999年由当年的沃卓斯基兄弟（Wachowskis）自编自导的系列科幻动作史诗，由基努·里维斯（Keanu Reeves）、劳伦斯·菲什伯恩（Laurence Fishburne）以及凯瑞-安·莫斯（Carrie-Anne Moss）等大牌明星主演。其讲述的是在反乌托邦的未来，由救世主尼奥（Neo）带领... (展开)
53 1回应 收起

> 更多影评 491篇

添加新讨论

## 讨论区 · · · · · ·

锡安真的是真实世界? | 来自mid | 26 回应 | 2022-10-09 15:29:36
看先过后，我就想，我们这世界不会是这样的，我们... | 来自流醉蝶舞 | 2 回应 | 2022-10-09 15:28:24
好希望史密斯赢啊，有没有相同想法的？ | 来自大泽乡 | 1 回应 | 2022-09-21 16:20:12
Imbd 评分怎么这么低 | 来自Bourne | 10 回应 | 2022-09-02 18:19:31
黑客3怎么下架了 | 来自埋藏的崔维兹 | 3 回应 | 2022-08-24 23:47:55

> 去这部影片的讨论区（全部125条）

## 关于《黑客帝国3：矩阵革命》的问题 · · · · · · ( 全部21个 )

- 这一战的意义是什么？ 3人回答
- 最后决战时刻史密斯为什么说这不公平？ 11人回答

> 全部21个问题

## 本片原声正在播放 · · · · · ·

去豆瓣音乐收听

## 以下片单推荐 · · · · · · ( 全部 )

- ★豆瓣高分电影榜★ （上）9.7-8.6分 (影志)
- 那些牛叉闪闪的片子 (家庭种菜笔记)
- 入选《第十放映室》影片之国外篇Ⅰ (心之旋影)
- {北美电影票房总排行} (荔枝超人)
- 带你进入不正常的世界 (DK小眼镜儿)

## 谁在看这部电影 · · · · · ·

- Joey
  11分钟前 看过
- 轩辕青佑
  13分钟前 看过
- momo
  18分钟前 想看

663977人看过 / 93082人想看

订阅黑客帝国3：矩阵革命的评论:
feed: rss 2.0